@@ -10,9 +10,9 @@
 #include "kconfigcompiler_test.h"
 #include <QDir>
 #include <QProcess>
+#include <QStandardPaths>
 #include <QString>
 #include <QTest>
-#include <qstandardpaths.h>
 
 // QT5 TODO QTEST_GUILESS_MAIN(KConfigCompiler_Test)
 QTEST_MAIN(KConfigCompiler_Test)
@@ -83,6 +83,10 @@ static CompilerTestSet testCases = {"test1.cpp",
                                     "test_param_minmax.h",
                                     "test_subgroups.cpp",
                                     "test_subgroups.h",
+                                    "test_time.cpp",
+                                    "test_time.h",
+                                    "test_kconfigconstructor.cpp",
+                                    "test_kconfigconstructor.h",
                                     nullptr};
 
 static CompilerTestSet testCasesToRun = {"Test1",
@@ -135,6 +139,8 @@ static CompilerTestSet testCasesToRun = {"Test1",
                                          "test_signal_cmake",
                                          "test_emptyentries_cmake",
                                          "test_subgroups_cmake",
+                                         "test_time_cmake",
+                                         "test_kconfigconstructor_cmake",
                                          nullptr};
 
 #if 0
@@ -184,7 +190,7 @@ void KConfigCompiler_Test::testBaselineComparison()
         appendFileDiff(fileRef.fileName(), file.fileName());
     }
 
-    QVERIFY(content == contentRef);
+    QCOMPARE(content, contentRef);
 }
 
 void KConfigCompiler_Test::testRunning_data()
