@@ -1,22 +1,9 @@
 /*
     This file is part of KOrganizer.
-    Copyright (c) 2000,2001 Cornelius Schumacher <schumacher@kde.org>
-    Copyright (c) 2003 Waldo Bastian <bastian@kde.org>
+    SPDX-FileCopyrightText: 2000, 2001 Cornelius Schumacher <schumacher@kde.org>
+    SPDX-FileCopyrightText: 2003 Waldo Bastian <bastian@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KCORECONFIGSKELETON_P_H
@@ -28,18 +15,19 @@ class KCoreConfigSkeletonPrivate
 {
 public:
     KCoreConfigSkeletonPrivate()
-        : mCurrentGroup(QStringLiteral("No Group")), mUseDefaults(false)
-    {}
+        : mCurrentGroup(QStringLiteral("No Group"))
+        , mUseDefaults(false)
+    {
+    }
     ~KCoreConfigSkeletonPrivate()
     {
-        KConfigSkeletonItem::List::ConstIterator it;
-        for (it = mItems.constBegin(); it != mItems.constEnd(); ++it) {
-            delete *it;
-        }
+        qDeleteAll(mItems);
     }
     QString mCurrentGroup;
 
-    KSharedConfig::Ptr mConfig; // pointer to KConfig object
+    // store the backend config only one should be set
+    KSharedConfig::Ptr mSharedConfig;
+    std::unique_ptr<KConfig> config;
 
     KConfigSkeletonItem::List mItems;
     KConfigSkeletonItem::Dict mItemDict;
@@ -53,7 +41,8 @@ public:
     KConfigSkeletonItemPrivate()
         : mIsImmutable(true)
         , mWriteFlags(KConfigBase::Normal)
-    {}
+    {
+    }
     virtual ~KConfigSkeletonItemPrivate();
     bool mIsImmutable; ///< Indicates this item is immutable
     KConfigBase::WriteConfigFlags mWriteFlags; ///< The flags to pass to calls of writeEntry() and revertToDefault()
@@ -61,10 +50,12 @@ public:
     QString mLabel; ///< The label for this item
     QString mToolTip; ///< The ToolTip text for this item
     QString mWhatsThis; ///< The What's This text for this item
+    KConfigGroup mConfigGroup; ///< KConfigGroup, allow to read/write item in nested groups
 
     // HACK: Necessary to avoid introducing new virtuals in KConfigSkeletonItem
     std::function<bool()> mIsDefaultImpl;
     std::function<bool()> mIsSaveNeededImpl;
+    std::function<QVariant()> mGetDefaultImpl;
 };
 
 class KPropertySkeletonItemPrivate : public KConfigSkeletonItemPrivate
@@ -86,7 +77,7 @@ public:
     const QVariant mConstDefaultValue;
     QVariant mReference;
     QVariant mLoadedValue;
+    std::function<void()> mNotifyFunction;
 };
 
-
 #endif
